==> ultracopier_0.3.1.0.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Teracopy/Languages/fr/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
<context>
    <name>InterfacePlugin</name>
    <message>
        <location filename="../../interface.cpp" line="76"/>
        <source>Total: %1 of %2</source>
        <translation>Total: %1 sur %2</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="77"/>
        <source>%1 of %2</source>
        <translation>%1 sur %2</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="212"/>
        <source>%1% done</source>
        <translation>%1% fait</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="159"/>
        <source>&amp;More</source>
        <translation>&amp;Plus</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="172"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="210"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="251"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuler</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="281"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://ultracopier.first-world.info/&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#0057ae;&quot;&gt;Support Ultracopier&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://ultracopier.first-world.info/&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#0057ae;&quot;&gt;Supporter Ultracopier&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="308"/>
        <source>Add file</source>
        <translation>Ajouter un fichier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="317"/>
        <source>Add folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="326"/>
        <source>Move file(s)</source>
        <translation>Déplacer des fichier(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="335"/>
        <source>Move folder</source>
        <translation>Déplacer un dossier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="344"/>
        <source>Copy file(s)</source>
        <translation>Copier des fichier(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="353"/>
        <source>Copy folder</source>
        <translation>Copier un dossier</translation>
    </message>
</context>
</TS>

==> ultracopier_1.4.0.6.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Teracopy/Languages/fr/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="95"/>
        <source>Total: %1 of %2</source>
        <translation>Total: %1 sur %2</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="96"/>
        <source>%1 of %2</source>
        <translation>%1 sur %2</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="250"/>
        <source>%1% done</source>
        <translatorcomment>Exemple: 90% fait</translatorcomment>
        <translation>%1% fait</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="159"/>
        <source>&amp;More</source>
        <translation>&amp;Plus</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="172"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="210"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="251"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuler</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="281"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://ultracopier.first-world.info/&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#0057ae;&quot;&gt;Support Ultracopier&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://ultracopier.first-world.info/&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#0057ae;&quot;&gt;Supporter Ultracopier&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="308"/>
        <source>Add file</source>
        <translation>Ajouter un fichier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="317"/>
        <source>Add folder</source>
        <translation>Ajouter un dossier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="326"/>
        <source>Move file(s)</source>
        <translation>Déplacer des fichier(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="335"/>
        <source>Move folder</source>
        <translation>Déplacer un dossier</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="344"/>
        <source>Copy file(s)</source>
        <translation>Copier des fichier(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="353"/>
        <source>Copy folder</source>
        <translation>Copier un dossier</translation>
    </message>
</context>
</TS>
